# frozen_string_literal: true

require_relative 'accepts_comments'

require_relative 'has_description'
require_relative 'has_elements'
require_relative 'has_options_initializer'
require_relative 'has_rows'
require_relative 'indentation'
